@@ -55,11 +55,9 @@ def deprecation_message(deprecated_in: str, removed_in: str, help_message: Optio
 
 
 def _deprecation_warning(message: str) -> None:
-    warnings.simplefilter("always", DeprecationWarning)  # turn off filter
-
-    warnings.warn(
-        message,
-        category=DeprecationWarning,
-        stacklevel=2,
-    )
-    warnings.simplefilter("default", DeprecationWarning)  # reset filter
+    with warnings.catch_warnings():  # temporarily override warning handling
+        warnings.warn(
+            message,
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
