@@ -698,21 +698,35 @@ def test_and() -> None:
     null = IsNull(Reference("a"))
     nan = IsNaN(Reference("b"))
     and_ = And(null, nan)
+
+    # Some syntactic sugar
+    assert and_ == null & nan
+
     assert str(and_) == f"And(left={str(null)}, right={str(nan)})"
     assert repr(and_) == f"And(left={repr(null)}, right={repr(nan)})"
     assert and_ == eval(repr(and_))
     assert and_ == pickle.loads(pickle.dumps(and_))
 
+    with pytest.raises(ValueError, match="Expected BooleanExpression, got: abc"):
+        null & "abc"  # type: ignore
+
 
 def test_or() -> None:
     null = IsNull(Reference("a"))
     nan = IsNaN(Reference("b"))
     or_ = Or(null, nan)
+
+    # Some syntactic sugar
+    assert or_ == null | nan
+
     assert str(or_) == f"Or(left={str(null)}, right={str(nan)})"
     assert repr(or_) == f"Or(left={repr(null)}, right={repr(nan)})"
     assert or_ == eval(repr(or_))
     assert or_ == pickle.loads(pickle.dumps(or_))
 
+    with pytest.raises(ValueError, match="Expected BooleanExpression, got: abc"):
+        null | "abc"  # type: ignore
+
 
 def test_not() -> None:
     null = IsNull(Reference("a"))
@@ -1160,6 +1174,34 @@ def test_eq_bound_expression(bound_reference_str: BoundReference[str]) -> None:
     )
 
 
+def test_nested_bind() -> None:
+    schema = Schema(NestedField(1, "foo", StructType(NestedField(2, "bar", StringType()))), schema_id=1)
+    bound = BoundIsNull(BoundReference(schema.find_field(2), schema.accessor_for_field(2)))
+    assert IsNull(Reference("foo.bar")).bind(schema) == bound
+
+
+def test_bind_dot_name() -> None:
+    schema = Schema(NestedField(1, "foo.bar", StringType()), schema_id=1)
+    bound = BoundIsNull(BoundReference(schema.find_field(1), schema.accessor_for_field(1)))
+    assert IsNull(Reference("foo.bar")).bind(schema) == bound
+
+
+def test_nested_bind_with_dot_name() -> None:
+    schema = Schema(NestedField(1, "foo.bar", StructType(NestedField(2, "baz", StringType()))), schema_id=1)
+    bound = BoundIsNull(BoundReference(schema.find_field(2), schema.accessor_for_field(2)))
+    assert IsNull(Reference("foo.bar.baz")).bind(schema) == bound
+
+
+def test_bind_ambiguous_name() -> None:
+    with pytest.raises(ValueError) as exc_info:
+        Schema(
+            NestedField(1, "foo", StructType(NestedField(2, "bar", StringType()))),
+            NestedField(3, "foo.bar", StringType()),
+            schema_id=1,
+        )
+    assert "Invalid schema, multiple fields for name foo.bar: 2 and 3" in str(exc_info)
+
+
 #   __  __      ___
 #  |  \/  |_  _| _ \_  _
 #  | |\/| | || |  _/ || |
