@@ -14,6 +14,8 @@
 #  KIND, either express or implied.  See the License for the
 #  specific language governing permissions and limitations
 #  under the License.
+from decimal import Decimal
+
 import pytest
 from pyparsing import ParseException
 
@@ -39,6 +41,7 @@ from pyiceberg.expressions import (
     Or,
     StartsWith,
 )
+from pyiceberg.expressions.literals import DecimalLiteral
 
 
 def test_always_true() -> None:
@@ -70,7 +73,6 @@ def test_equals_false() -> None:
 def test_is_null() -> None:
     assert IsNull("foo") == parser.parse("foo is null")
     assert IsNull("foo") == parser.parse("foo IS NULL")
-    assert IsNull("foo") == parser.parse("table.foo IS NULL")
 
 
 def test_not_null() -> None:
@@ -217,3 +219,20 @@ def test_with_function() -> None:
         parser.parse("foo = 1 and lower(bar) = '2'")
 
     assert "Expected end of text, found 'and'" in str(exc_info)
+
+
+def test_nested_fields() -> None:
+    assert EqualTo("foo.bar", "data") == parser.parse("foo.bar = 'data'")
+    assert LessThan("location.x", DecimalLiteral(Decimal(52.00))) == parser.parse("location.x < 52.00")
+
+
+def test_quoted_column_with_dots() -> None:
+    with pytest.raises(ParseException) as exc_info:
+        parser.parse("\"foo.bar\".baz = 'data'")
+
+    assert "Expected '\"', found '.'" in str(exc_info.value)
+
+    with pytest.raises(ParseException) as exc_info:
+        parser.parse("'foo.bar'.baz = 'data'")
+
+    assert "Expected <= | <> | < | >= | > | == | = | !=, found '.'" in str(exc_info.value)
