@@ -33,6 +33,7 @@ from pyiceberg.expressions import (
 )
 from pyiceberg.expressions.literals import literal
 from pyiceberg.io.pyarrow import (
+    UnsupportedPyArrowTypeException,
     _ConvertToArrowSchema,
     _ConvertToIceberg,
     _ConvertToIcebergWithoutIDs,
@@ -239,11 +240,13 @@ def test_pyarrow_variable_binary_to_iceberg() -> None:
 
 
 def test_pyarrow_struct_to_iceberg() -> None:
-    pyarrow_struct = pa.struct([
-        pa.field("foo", pa.string(), nullable=True, metadata={"PARQUET:field_id": "1", "doc": "foo doc"}),
-        pa.field("bar", pa.int32(), nullable=False, metadata={"PARQUET:field_id": "2"}),
-        pa.field("baz", pa.bool_(), nullable=True, metadata={"PARQUET:field_id": "3"}),
-    ])
+    pyarrow_struct = pa.struct(
+        [
+            pa.field("foo", pa.string(), nullable=True, metadata={"PARQUET:field_id": "1", "doc": "foo doc"}),
+            pa.field("bar", pa.int32(), nullable=False, metadata={"PARQUET:field_id": "2"}),
+            pa.field("baz", pa.bool_(), nullable=True, metadata={"PARQUET:field_id": "3"}),
+        ]
+    )
     expected = StructType(
         NestedField(field_id=1, name="foo", field_type=StringType(), required=False, doc="foo doc"),
         NestedField(field_id=2, name="bar", field_type=IntegerType(), required=True),
@@ -344,84 +347,94 @@ def test_round_schema_large_string() -> None:
 
 
 def test_simple_schema_has_missing_ids() -> None:
-    schema = pa.schema([
-        pa.field("foo", pa.string(), nullable=False),
-    ])
+    schema = pa.schema(
+        [
+            pa.field("foo", pa.string(), nullable=False),
+        ]
+    )
     visitor = _HasIds()
     has_ids = visit_pyarrow(schema, visitor)
     assert not has_ids
 
 
 def test_simple_schema_has_missing_ids_partial() -> None:
-    schema = pa.schema([
-        pa.field("foo", pa.string(), nullable=False, metadata={"PARQUET:field_id": "1", "doc": "foo doc"}),
-        pa.field("bar", pa.int32(), nullable=False),
-    ])
+    schema = pa.schema(
+        [
+            pa.field("foo", pa.string(), nullable=False, metadata={"PARQUET:field_id": "1", "doc": "foo doc"}),
+            pa.field("bar", pa.int32(), nullable=False),
+        ]
+    )
     visitor = _HasIds()
     has_ids = visit_pyarrow(schema, visitor)
     assert not has_ids
 
 
 def test_nested_schema_has_missing_ids() -> None:
-    schema = pa.schema([
-        pa.field("foo", pa.string(), nullable=False),
-        pa.field(
-            "quux",
-            pa.map_(
-                pa.string(),
-                pa.map_(pa.string(), pa.int32()),
+    schema = pa.schema(
+        [
+            pa.field("foo", pa.string(), nullable=False),
+            pa.field(
+                "quux",
+                pa.map_(
+                    pa.string(),
+                    pa.map_(pa.string(), pa.int32()),
+                ),
+                nullable=False,
             ),
-            nullable=False,
-        ),
-    ])
+        ]
+    )
     visitor = _HasIds()
     has_ids = visit_pyarrow(schema, visitor)
     assert not has_ids
 
 
 def test_nested_schema_has_ids() -> None:
-    schema = pa.schema([
-        pa.field("foo", pa.string(), nullable=False, metadata={"PARQUET:field_id": "1", "doc": "foo doc"}),
-        pa.field(
-            "quux",
-            pa.map_(
-                pa.field("key", pa.string(), nullable=False, metadata={"PARQUET:field_id": "7"}),
-                pa.field(
-                    "value",
-                    pa.map_(
-                        pa.field("key", pa.string(), nullable=False, metadata={"PARQUET:field_id": "9"}),
-                        pa.field("value", pa.int32(), metadata={"PARQUET:field_id": "10"}),
+    schema = pa.schema(
+        [
+            pa.field("foo", pa.string(), nullable=False, metadata={"PARQUET:field_id": "1", "doc": "foo doc"}),
+            pa.field(
+                "quux",
+                pa.map_(
+                    pa.field("key", pa.string(), nullable=False, metadata={"PARQUET:field_id": "7"}),
+                    pa.field(
+                        "value",
+                        pa.map_(
+                            pa.field("key", pa.string(), nullable=False, metadata={"PARQUET:field_id": "9"}),
+                            pa.field("value", pa.int32(), metadata={"PARQUET:field_id": "10"}),
+                        ),
+                        nullable=False,
+                        metadata={"PARQUET:field_id": "8"},
                     ),
-                    nullable=False,
-                    metadata={"PARQUET:field_id": "8"},
                 ),
+                nullable=False,
+                metadata={"PARQUET:field_id": "6", "doc": "quux doc"},
             ),
-            nullable=False,
-            metadata={"PARQUET:field_id": "6", "doc": "quux doc"},
-        ),
-    ])
+        ]
+    )
     visitor = _HasIds()
     has_ids = visit_pyarrow(schema, visitor)
     assert has_ids
 
 
 def test_nested_schema_has_partial_missing_ids() -> None:
-    schema = pa.schema([
-        pa.field("foo", pa.string(), nullable=False, metadata={"PARQUET:field_id": "1", "doc": "foo doc"}),
-        pa.field(
-            "quux",
-            pa.map_(
-                pa.field("key", pa.string(), nullable=False, metadata={"PARQUET:field_id": "7"}),
-                pa.field(
-                    "value",
-                    pa.map_(pa.field("key", pa.string(), nullable=False), pa.field("value", pa.int32())),
-                    nullable=False,
+    schema = pa.schema(
+        [
+            pa.field("foo", pa.string(), nullable=False, metadata={"PARQUET:field_id": "1", "doc": "foo doc"}),
+            pa.field(
+                "quux",
+                pa.map_(
+                    pa.field("key", pa.string(), nullable=False, metadata={"PARQUET:field_id": "7"}),
+                    pa.field(
+                        "value",
+                        pa.map_(pa.field("key", pa.string(), nullable=False), pa.field("value", pa.int32())),
+                        nullable=False,
+                    ),
                 ),
+                nullable=False,
+                metadata={"PARQUET:field_id": "6", "doc": "quux doc"},
             ),
-            nullable=False,
-            metadata={"PARQUET:field_id": "6", "doc": "quux doc"},
-        ),
-    ])
+        ]
+    )
     visitor = _HasIds()
     has_ids = visit_pyarrow(schema, visitor)
     assert not has_ids
@@ -441,11 +454,13 @@ def test_simple_pyarrow_schema_to_schema_missing_ids_using_name_mapping(
     pyarrow_schema_simple_without_ids: pa.Schema, iceberg_schema_simple: Schema
 ) -> None:
     schema = pyarrow_schema_simple_without_ids
-    name_mapping = NameMapping([
-        MappedField(field_id=1, names=["foo"]),
-        MappedField(field_id=2, names=["bar"]),
-        MappedField(field_id=3, names=["baz"]),
-    ])
+    name_mapping = NameMapping(
+        [
+            MappedField(field_id=1, names=["foo"]),
+            MappedField(field_id=2, names=["bar"]),
+            MappedField(field_id=3, names=["baz"]),
+        ]
+    )
 
     assert pyarrow_to_schema(schema, name_mapping) == iceberg_schema_simple
 
@@ -454,9 +469,11 @@ def test_simple_pyarrow_schema_to_schema_missing_ids_using_name_mapping_partial_
     pyarrow_schema_simple_without_ids: pa.Schema,
 ) -> None:
     schema = pyarrow_schema_simple_without_ids
-    name_mapping = NameMapping([
-        MappedField(field_id=1, names=["foo"]),
-    ])
+    name_mapping = NameMapping(
+        [
+            MappedField(field_id=1, names=["foo"]),
+        ]
+    )
     with pytest.raises(ValueError) as exc_info:
         _ = pyarrow_to_schema(schema, name_mapping)
     assert "Could not find field with name: bar" in str(exc_info.value)
@@ -467,83 +484,89 @@ def test_nested_pyarrow_schema_to_schema_missing_ids_using_name_mapping(
 ) -> None:
     schema = pyarrow_schema_nested_without_ids
 
-    name_mapping = NameMapping([
-        MappedField(field_id=1, names=["foo"]),
-        MappedField(field_id=2, names=["bar"]),
-        MappedField(field_id=3, names=["baz"]),
-        MappedField(field_id=4, names=["qux"], fields=[MappedField(field_id=5, names=["element"])]),
-        MappedField(
-            field_id=6,
-            names=["quux"],
-            fields=[
-                MappedField(field_id=7, names=["key"]),
-                MappedField(
-                    field_id=8,
-                    names=["value"],
-                    fields=[
-                        MappedField(field_id=9, names=["key"]),
-                        MappedField(field_id=10, names=["value"]),
-                    ],
-                ),
-            ],
-        ),
-        MappedField(
-            field_id=11,
-            names=["location"],
-            fields=[
-                MappedField(
-                    field_id=12,
-                    names=["element"],
-                    fields=[
-                        MappedField(field_id=13, names=["latitude"]),
-                        MappedField(field_id=14, names=["longitude"]),
-                    ],
-                )
-            ],
-        ),
-        MappedField(
-            field_id=15,
-            names=["person"],
-            fields=[
-                MappedField(field_id=16, names=["name"]),
-                MappedField(field_id=17, names=["age"]),
-            ],
-        ),
-    ])
+    name_mapping = NameMapping(
+        [
+            MappedField(field_id=1, names=["foo"]),
+            MappedField(field_id=2, names=["bar"]),
+            MappedField(field_id=3, names=["baz"]),
+            MappedField(field_id=4, names=["qux"], fields=[MappedField(field_id=5, names=["element"])]),
+            MappedField(
+                field_id=6,
+                names=["quux"],
+                fields=[
+                    MappedField(field_id=7, names=["key"]),
+                    MappedField(
+                        field_id=8,
+                        names=["value"],
+                        fields=[
+                            MappedField(field_id=9, names=["key"]),
+                            MappedField(field_id=10, names=["value"]),
+                        ],
+                    ),
+                ],
+            ),
+            MappedField(
+                field_id=11,
+                names=["location"],
+                fields=[
+                    MappedField(
+                        field_id=12,
+                        names=["element"],
+                        fields=[
+                            MappedField(field_id=13, names=["latitude"]),
+                            MappedField(field_id=14, names=["longitude"]),
+                        ],
+                    )
+                ],
+            ),
+            MappedField(
+                field_id=15,
+                names=["person"],
+                fields=[
+                    MappedField(field_id=16, names=["name"]),
+                    MappedField(field_id=17, names=["age"]),
+                ],
+            ),
+        ]
+    )
 
     assert pyarrow_to_schema(schema, name_mapping) == iceberg_schema_nested
 
 
 def test_pyarrow_schema_to_schema_missing_ids_using_name_mapping_nested_missing_id() -> None:
-    schema = pa.schema([
-        pa.field("foo", pa.string(), nullable=False),
-        pa.field(
-            "quux",
-            pa.map_(
-                pa.string(),
-                pa.map_(pa.string(), pa.int32()),
-            ),
-            nullable=False,
-        ),
-    ])
-
-    name_mapping = NameMapping([
-        MappedField(field_id=1, names=["foo"]),
-        MappedField(
-            field_id=6,
-            names=["quux"],
-            fields=[
-                MappedField(field_id=7, names=["key"]),
-                MappedField(
-                    field_id=8,
-                    names=["value"],
-                    fields=[
-                        MappedField(field_id=10, names=["value"]),
-                    ],
+    schema = pa.schema(
+        [
+            pa.field("foo", pa.string(), nullable=False),
+            pa.field(
+                "quux",
+                pa.map_(
+                    pa.string(),
+                    pa.map_(pa.string(), pa.int32()),
                 ),
-            ],
-        ),
-    ])
+                nullable=False,
+            ),
+        ]
+    )
+
+    name_mapping = NameMapping(
+        [
+            MappedField(field_id=1, names=["foo"]),
+            MappedField(
+                field_id=6,
+                names=["quux"],
+                fields=[
+                    MappedField(field_id=7, names=["key"]),
+                    MappedField(
+                        field_id=8,
+                        names=["value"],
+                        fields=[
+                            MappedField(field_id=10, names=["value"]),
+                        ],
+                    ),
+                ],
+            ),
+        ]
+    )
     with pytest.raises(ValueError) as exc_info:
         _ = pyarrow_to_schema(schema, name_mapping)
     assert "Could not find field with name: quux.value.key" in str(exc_info.value)
@@ -562,41 +585,132 @@ def test_pyarrow_schema_to_schema_fresh_ids_nested_schema(
 
 
 def test_pyarrow_schema_ensure_large_types(pyarrow_schema_nested_without_ids: pa.Schema) -> None:
-    expected_schema = pa.schema([
-        pa.field("foo", pa.large_string(), nullable=False),
-        pa.field("bar", pa.int32(), nullable=False),
-        pa.field("baz", pa.bool_(), nullable=True),
-        pa.field("qux", pa.large_list(pa.large_string()), nullable=False),
-        pa.field(
-            "quux",
-            pa.map_(
-                pa.large_string(),
-                pa.map_(pa.large_string(), pa.int32()),
+    expected_schema = pa.schema(
+        [
+            pa.field("foo", pa.large_string(), nullable=False),
+            pa.field("bar", pa.int32(), nullable=False),
+            pa.field("baz", pa.bool_(), nullable=True),
+            pa.field("qux", pa.large_list(pa.large_string()), nullable=False),
+            pa.field(
+                "quux",
+                pa.map_(
+                    pa.large_string(),
+                    pa.map_(pa.large_string(), pa.int32()),
+                ),
+                nullable=False,
             ),
-            nullable=False,
-        ),
-        pa.field(
-            "location",
-            pa.large_list(
-                pa.struct([
-                    pa.field("latitude", pa.float32(), nullable=False),
-                    pa.field("longitude", pa.float32(), nullable=False),
-                ]),
+            pa.field(
+                "location",
+                pa.large_list(
+                    pa.struct(
+                        [
+                            pa.field("latitude", pa.float32(), nullable=False),
+                            pa.field("longitude", pa.float32(), nullable=False),
+                        ]
+                    ),
+                ),
+                nullable=False,
             ),
-            nullable=False,
-        ),
-        pa.field(
-            "person",
-            pa.struct([
-                pa.field("name", pa.large_string(), nullable=True),
-                pa.field("age", pa.int32(), nullable=False),
-            ]),
-            nullable=True,
-        ),
-    ])
+            pa.field(
+                "person",
+                pa.struct(
+                    [
+                        pa.field("name", pa.large_string(), nullable=True),
+                        pa.field("age", pa.int32(), nullable=False),
+                    ]
+                ),
+                nullable=True,
+            ),
+        ]
+    )
     assert _pyarrow_schema_ensure_large_types(pyarrow_schema_nested_without_ids) == expected_schema
 
 
+def test_pyarrow_schema_unsupported_type() -> None:
+    unsupported_field = pa.field("latitude", pa.decimal256(20, 26), nullable=False, metadata={"PARQUET:field_id": "2"})
+    schema = pa.schema(
+        [
+            pa.field("foo", pa.string(), nullable=False, metadata={"PARQUET:field_id": "1"}),
+            pa.field(
+                "location",
+                pa.large_list(
+                    pa.field(
+                        "item",
+                        pa.struct(
+                            [
+                                unsupported_field,
+                                pa.field("longitude", pa.float32(), nullable=False, metadata={"PARQUET:field_id": "3"}),
+                            ]
+                        ),
+                        metadata={"PARQUET:field_id": "4"},
+                    )
+                ),
+                nullable=False,
+                metadata={"PARQUET:field_id": "5"},
+            ),
+        ],
+        metadata={"PARQUET:field_id": "6"},
+    )
+    with pytest.raises(
+        UnsupportedPyArrowTypeException, match=re.escape("Column 'latitude' has an unsupported type: decimal256(20, 26)")
+    ) as exc_info:
+        pyarrow_to_schema(schema)
+    assert exc_info.value.field == unsupported_field
+    exception_cause = exc_info.value.__cause__
+    assert isinstance(exception_cause, TypeError)
+    assert "Unsupported type: decimal256(20, 26)" in exception_cause.args[0]
+
+    unsupported_field = pa.field(
+        "quux",
+        pa.map_(
+            pa.field("key", pa.string(), nullable=False, metadata={"PARQUET:field_id": "2"}),
+            pa.field(
+                "value",
+                pa.map_(
+                    pa.field("key", pa.string(), nullable=False, metadata={"PARQUET:field_id": "5"}),
+                    pa.field("value", pa.decimal256(2, 3), metadata={"PARQUET:field_id": "6"}),
+                ),
+                nullable=False,
+                metadata={"PARQUET:field_id": "4"},
+            ),
+        ),
+        nullable=False,
+        metadata={"PARQUET:field_id": "3"},
+    )
+    schema = pa.schema(
+        [
+            pa.field("foo", pa.string(), nullable=False, metadata={"PARQUET:field_id": "1"}),
+            unsupported_field,
+        ]
+    )
+    with pytest.raises(
+        UnsupportedPyArrowTypeException,
+        match=re.escape("Column 'quux' has an unsupported type: map<string, map<string, decimal256(2, 3)>>"),
+    ) as exc_info:
+        pyarrow_to_schema(schema)
+    assert exc_info.value.field == unsupported_field
+    exception_cause = exc_info.value.__cause__
+    assert isinstance(exception_cause, TypeError)
+    assert "Unsupported type: decimal256(2, 3)" in exception_cause.args[0]
+
+    unsupported_field = pa.field("foo", pa.timestamp(unit="ns"), nullable=False, metadata={"PARQUET:field_id": "1"})
+    schema = pa.schema(
+        [
+            unsupported_field,
+            pa.field("bar", pa.int32(), nullable=False, metadata={"PARQUET:field_id": "2"}),
+        ]
+    )
+    with pytest.raises(
+        UnsupportedPyArrowTypeException,
+        match=re.escape("Column 'foo' has an unsupported type: timestamp[ns]"),
+    ) as exc_info:
+        pyarrow_to_schema(schema)
+    assert exc_info.value.field == unsupported_field
+    exception_cause = exc_info.value.__cause__
+    assert isinstance(exception_cause, TypeError)
+    assert "Iceberg does not yet support 'ns' timestamp precision" in exception_cause.args[0]
+
+
 def test_pyarrow_schema_round_trip_ensure_large_types_and_then_small_types(pyarrow_schema_nested_without_ids: pa.Schema) -> None:
     schema_with_large_types = _pyarrow_schema_ensure_large_types(pyarrow_schema_nested_without_ids)
     assert _pyarrow_schema_ensure_small_types(schema_with_large_types) == pyarrow_schema_nested_without_ids
