@@ -71,9 +71,17 @@ Notes:
         - -4.5F is -1 * 2ˆ2 * 1.125 and encoded as 11000000|10010000|0...0 in binary
         - 00000000 -> 0, 00000000 -> 0, 10010000 -> 144 (-112), 11000000 -> 192 (-64),
 """
+
 import struct
 import uuid
+from datetime import (
+    date,
+    datetime,
+    time,
+    timezone,
+)
 from decimal import Decimal
+from typing import Any, Union
 
 import pytest
 
@@ -89,6 +97,7 @@ from pyiceberg.types import (
     FloatType,
     IntegerType,
     LongType,
+    PrimitiveType,
     StringType,
     TimestampType,
     TimestamptzType,
@@ -111,7 +120,7 @@ from pyiceberg.types import (
         (Decimal("0.0000001"), 1),
     ],
 )
-def test_decimal_to_unscaled(value, expected_result):
+def test_decimal_to_unscaled(value: Decimal, expected_result: int) -> None:
     """Test converting a decimal to an unscaled value"""
     assert decimal_util.decimal_to_unscaled(value=value) == expected_result
 
@@ -129,7 +138,7 @@ def test_decimal_to_unscaled(value, expected_result):
         (1, 7, Decimal("0.0000001")),
     ],
 )
-def test_unscaled_to_decimal(unscaled, scale, expected_result):
+def test_unscaled_to_decimal(unscaled: int, scale: int, expected_result: Decimal) -> None:
     """Test converting an unscaled value to a decimal with a specified scale"""
     assert decimal_util.unscaled_to_decimal(unscaled=unscaled, scale=scale) == expected_result
 
@@ -153,7 +162,7 @@ def test_unscaled_to_decimal(unscaled, scale, expected_result):
         (BinaryType(), "foo", b"foo"),
     ],
 )
-def test_partition_to_py(primitive_type, value_str, expected_result):
+def test_partition_to_py(primitive_type: PrimitiveType, value_str: str, expected_result: Any) -> None:
     """Test converting a partition value to a python built-in"""
     assert conversions.partition_to_py(primitive_type, value_str) == expected_result
 
@@ -177,9 +186,9 @@ def test_partition_to_py(primitive_type, value_str, expected_result):
         (UUIDType()),
     ],
 )
-def test_none_partition_values(primitive_type):
+def test_none_partition_values(primitive_type: PrimitiveType) -> None:
     """Test converting a partition value to a python built-in"""
-    assert conversions.partition_to_py(primitive_type, None) is None
+    assert conversions.partition_to_py(primitive_type, None) is None  # type: ignore
 
 
 @pytest.mark.parametrize(
@@ -201,7 +210,7 @@ def test_none_partition_values(primitive_type):
         (UUIDType()),
     ],
 )
-def test_hive_default_partition_values(primitive_type):
+def test_hive_default_partition_values(primitive_type: PrimitiveType) -> None:
     """Test converting a partition value to a python built-in"""
     assert conversions.partition_to_py(primitive_type, "__HIVE_DEFAULT_PARTITION__") is None
 
@@ -227,7 +236,9 @@ def test_hive_default_partition_values(primitive_type):
         (LongType(), "123456700", False),
     ],
 )
-def test_partition_to_py_raise_on_incorrect_precision_or_scale(primitive_type, value, should_raise):
+def test_partition_to_py_raise_on_incorrect_precision_or_scale(
+    primitive_type: PrimitiveType, value: str, should_raise: bool
+) -> None:
     if should_raise:
         with pytest.raises(ValueError) as exc_info:
             conversions.partition_to_py(primitive_type, value)
@@ -260,9 +271,9 @@ def test_partition_to_py_raise_on_incorrect_precision_or_scale(primitive_type, v
         (
             UUIDType(),
             b"\xf7\x9c>\tg|K\xbd\xa4y?4\x9c\xb7\x85\xe7",
-            uuid.UUID("f79c3e09-677c-4bbd-a479-3f349cb785e7"),
+            b"\xf7\x9c>\tg|K\xbd\xa4y?4\x9c\xb7\x85\xe7",
         ),
-        (UUIDType(), b"\xf7\x9c>\tg|K\xbd\xa4y?4\x9c\xb7\x85\xe7", uuid.UUID("f79c3e09-677c-4bbd-a479-3f349cb785e7")),
+        (UUIDType(), b"\xf7\x9c>\tg|K\xbd\xa4y?4\x9c\xb7\x85\xe7", b"\xf7\x9c>\tg|K\xbd\xa4y?4\x9c\xb7\x85\xe7"),
         (FixedType(3), b"foo", b"foo"),
         (BinaryType(), b"foo", b"foo"),
         (DecimalType(5, 2), b"\x30\x39", Decimal("123.45")),
@@ -270,7 +281,7 @@ def test_partition_to_py_raise_on_incorrect_precision_or_scale(primitive_type, v
         (DecimalType(7, 4), b"\xff\xed\x29\x79", Decimal("-123.4567")),
     ],
 )
-def test_from_bytes(primitive_type, b, result):
+def test_from_bytes(primitive_type: PrimitiveType, b: bytes, result: Any) -> None:
     """Test converting from bytes"""
     assert conversions.from_bytes(primitive_type, b) == result
 
@@ -298,9 +309,9 @@ def test_from_bytes(primitive_type, b, result):
         (
             UUIDType(),
             b"\xf7\x9c>\tg|K\xbd\xa4y?4\x9c\xb7\x85\xe7",
-            uuid.UUID("f79c3e09-677c-4bbd-a479-3f349cb785e7"),
+            b"\xf7\x9c>\tg|K\xbd\xa4y?4\x9c\xb7\x85\xe7",
         ),
-        (UUIDType(), b"\xf7\x9c>\tg|K\xbd\xa4y?4\x9c\xb7\x85\xe7", uuid.UUID("f79c3e09-677c-4bbd-a479-3f349cb785e7")),
+        (UUIDType(), b"\xf7\x9c>\tg|K\xbd\xa4y?4\x9c\xb7\x85\xe7", b"\xf7\x9c>\tg|K\xbd\xa4y?4\x9c\xb7\x85\xe7"),
         (FixedType(3), b"foo", b"foo"),
         (BinaryType(), b"foo", b"foo"),
         (DecimalType(5, 2), b"\x30\x39", Decimal("123.45")),
@@ -322,7 +333,7 @@ def test_from_bytes(primitive_type, b, result):
         (FloatType(), b"\x19\x04\x9e?", struct.unpack("<f", struct.pack("<f", 1.2345))[0]),
     ],
 )
-def test_round_trip_conversion(primitive_type, b, result):
+def test_round_trip_conversion(primitive_type: PrimitiveType, b: bytes, result: Any) -> None:
     """Test round trip conversions of calling `conversions.from_bytes` and then `conversions.to_bytes` on the result"""
     value_from_bytes = conversions.from_bytes(primitive_type, b)
     assert value_from_bytes == result
@@ -331,6 +342,22 @@ def test_round_trip_conversion(primitive_type, b, result):
     assert bytes_from_value == b
 
 
+@pytest.mark.parametrize(
+    "primitive_type, v, result",
+    [
+        (
+            UUIDType(),
+            uuid.UUID("f79c3e09-677c-4bbd-a479-3f349cb785e7"),
+            b"\xf7\x9c>\tg|K\xbd\xa4y?4\x9c\xb7\x85\xe7",
+        ),
+        (UUIDType(), uuid.UUID("f79c3e09-677c-4bbd-a479-3f349cb785e7"), b"\xf7\x9c>\tg|K\xbd\xa4y?4\x9c\xb7\x85\xe7"),
+    ],
+)
+def test_uuid_to_bytes(primitive_type: PrimitiveType, v: Any, result: bytes) -> None:
+    bytes_from_value = conversions.to_bytes(primitive_type, v)
+    assert bytes_from_value == result
+
+
 @pytest.mark.parametrize(
     "primitive_type, b, result",
     [
@@ -402,7 +429,7 @@ def test_round_trip_conversion(primitive_type, b, result):
         (DecimalType(31, 26), b"\x0f\x94\xec\xad\xa5C<]\xdePf\xd6N", Decimal("12345.12345678912345678912345678")),
     ],
 )
-def test_round_trip_conversion_large_decimals(primitive_type, b, result):
+def test_round_trip_conversion_large_decimals(primitive_type: PrimitiveType, b: bytes, result: Any) -> None:
     """Test round trip conversions of calling `conversions.from_bytes` and then `conversions.to_bytes` on the result"""
     value_from_bytes = conversions.from_bytes(primitive_type, b)
     assert value_from_bytes == result
@@ -421,7 +448,7 @@ def test_round_trip_conversion_large_decimals(primitive_type, b, result):
         (DecimalType(20, 1), Decimal("9999999999999999999.9")),
     ],
 )
-def test_max_value_round_trip_conversion(primitive_type, expected_max_value):
+def test_max_value_round_trip_conversion(primitive_type: DecimalType, expected_max_value: Decimal) -> None:
     """Test round trip conversions of maximum DecimalType values"""
     b = conversions.to_bytes(primitive_type, expected_max_value)
     value_from_bytes = conversions.from_bytes(primitive_type, b)
@@ -439,7 +466,7 @@ def test_max_value_round_trip_conversion(primitive_type, expected_max_value):
         (DecimalType(20, 1), Decimal("-9999999999999999999.9")),
     ],
 )
-def test_min_value_round_trip_conversion(primitive_type, expected_min_value):
+def test_min_value_round_trip_conversion(primitive_type: DecimalType, expected_min_value: Decimal) -> None:
     """Test round trip conversions of minimum DecimalType values"""
     b = conversions.to_bytes(primitive_type, expected_min_value)
     value_from_bytes = conversions.from_bytes(primitive_type, b)
@@ -447,23 +474,23 @@ def test_min_value_round_trip_conversion(primitive_type, expected_min_value):
     assert value_from_bytes == expected_min_value
 
 
-def test_raise_on_unregistered_type():
+def test_raise_on_unregistered_type() -> None:
     """Test raising when a conversion is attempted for a type that has no registered method"""
 
     class FooUnknownType:
-        def __repr__(self):
+        def __repr__(self) -> str:
             return "FooUnknownType()"
 
     with pytest.raises(TypeError) as exc_info:
-        conversions.partition_to_py(FooUnknownType(), "foo")
+        conversions.partition_to_py(FooUnknownType(), "foo")  # type: ignore
     assert "Cannot convert 'foo' to unsupported type: FooUnknownType()" in str(exc_info.value)
 
     with pytest.raises(TypeError) as exc_info:
-        conversions.to_bytes(FooUnknownType(), "foo")
+        conversions.to_bytes(FooUnknownType(), "foo")  # type: ignore
     assert "scale does not match FooUnknownType()" in str(exc_info.value)
 
     with pytest.raises(TypeError) as exc_info:
-        conversions.from_bytes(FooUnknownType(), b"foo")
+        conversions.from_bytes(FooUnknownType(), b"foo")  # type: ignore
     assert "Cannot deserialize bytes, type FooUnknownType() not supported: b'foo'" in str(exc_info.value)
 
 
@@ -498,8 +525,23 @@ def test_raise_on_unregistered_type():
         ),
     ],
 )
-def test_raise_on_incorrect_precision_or_scale(primitive_type, value, expected_error_message):
+def test_raise_on_incorrect_precision_or_scale(primitive_type: DecimalType, value: Decimal, expected_error_message: str) -> None:
     with pytest.raises(ValueError) as exc_info:
         conversions.to_bytes(primitive_type, value)
 
     assert expected_error_message in str(exc_info.value)
+
+
+@pytest.mark.parametrize(
+    "primitive_type, value, expected_bytes",
+    [
+        (TimestampType(), datetime(2023, 3, 1, 19, 25, 0), b"\x00\xbb\r\xab\xdb\xf5\x05\x00"),
+        (TimestamptzType(), datetime(2023, 3, 1, 19, 25, 0, tzinfo=timezone.utc), b"\x00\xbb\r\xab\xdb\xf5\x05\x00"),
+        (DateType(), date(2023, 3, 1), b"\xd9K\x00\x00"),
+        (TimeType(), time(12, 30, 45, 500000), b"`\xc8\xeb|\n\x00\x00\x00"),
+    ],
+)
+def test_datetime_obj_to_bytes(primitive_type: PrimitiveType, value: Union[datetime, date, time], expected_bytes: bytes) -> None:
+    bytes_from_value = conversions.to_bytes(primitive_type, value)
+
+    assert bytes_from_value == expected_bytes
